@@ -27,10 +27,10 @@ struct json_iter;
  */
 enum json_type {
 	JSON_UNDEFINED = 0,
-	JSON_OBJECT = 1,
-	JSON_ARRAY = 2,
-	JSON_STRING = 3,
-	JSON_PRIMITIVE = 4
+	JSON_OBJECT = 1 << 0,
+	JSON_ARRAY = 1 << 1,
+	JSON_STRING = 1 << 2,
+	JSON_PRIMITIVE = 1 << 3,
 };
 
 enum json_flag {
@@ -85,7 +85,7 @@ void json_iter_init(struct json_iter *iter, struct json_contents *c);
  * other types are encountered.
  *
  * JSON_OPTIONAL string values will point to NULL if not found
- * JSON_OPTIONAL objects/primitives can be checked with json_object_is_valid.
+ * JSON_OPTIONAL objects/primitives can be checked with json_iter_is_valid.
  */
 bool json_iter_parse(struct json_iter *iter, enum json_type type, ...);
 
